==> haskell-statistics-0.15.2.0-190-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-statistics.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 statistics
version:              0.15.2.0
visibility:           public
id:                   statistics-0.15.2.0-G7p0B75LaSC8lLGqvRXHtV
key:                  statistics-0.15.2.0-G7p0B75LaSC8lLGqvRXHtV
license:              BSD-2-Clause
copyright:            2009-2014 Bryan O'\''Sullivan
maintainer:
    Bryan O'\''Sullivan <bos@serpentine.com>, Alexey Khudaykov <alexey.skladnoy@gmail.com>

author:
    Bryan O'\''Sullivan <bos@serpentine.com>, Alexey Khudaykov <alexey.skladnoy@gmail.com>

homepage:             https://github.com/bos/statistics
synopsis:             A library of statistical types, data, and functions
description:
    This library provides a number of common functions and types useful
    in statistics.  We focus on high performance, numerical robustness,
    and use of good algorithms.  Where possible, we provide
    references to the statistical literature.

    The library'\''s facilities can be divided into four broad categories:

    * Working with widely used discrete and continuous probability
    distributions.  (There are dozens of exotic distributions in use;
    we focus on the most common.)

    * Computing with sample data: quantile estimation, kernel density
    estimation, histograms, bootstrap methods, significance testing,
    and regression and autocorrelation analysis.

    * Random variate generation under several different distributions.

    * Common statistical tests for significant differences between
    samples.

category:             Math, Statistics
abi:                  7faf39a9713596022c46f71b43bb0f3f
exposed:              True
exposed-modules:
    Statistics.Autocorrelation Statistics.ConfidenceInt
    Statistics.Correlation Statistics.Correlation.Kendall
    Statistics.Distribution Statistics.Distribution.Beta
    Statistics.Distribution.Binomial
    Statistics.Distribution.CauchyLorentz
    Statistics.Distribution.ChiSquared
    Statistics.Distribution.DiscreteUniform
    Statistics.Distribution.Exponential
    Statistics.Distribution.FDistribution Statistics.Distribution.Gamma
    Statistics.Distribution.Geometric
    Statistics.Distribution.Hypergeometric
    Statistics.Distribution.Laplace Statistics.Distribution.Normal
    Statistics.Distribution.Poisson Statistics.Distribution.StudentT
    Statistics.Distribution.Transform Statistics.Distribution.Uniform
    Statistics.Function Statistics.Quantile Statistics.Regression
    Statistics.Resampling Statistics.Resampling.Bootstrap
    Statistics.Sample Statistics.Sample.Histogram
    Statistics.Sample.Internal Statistics.Sample.KernelDensity
    Statistics.Sample.KernelDensity.Simple Statistics.Sample.Normalize
    Statistics.Sample.Powers Statistics.Test.ChiSquared
    Statistics.Test.KolmogorovSmirnov Statistics.Test.KruskalWallis
    Statistics.Test.MannWhitneyU Statistics.Test.StudentT
    Statistics.Test.Types Statistics.Test.WilcoxonT
    Statistics.Transform Statistics.Types

hidden-modules:
    Statistics.Distribution.Poisson.Internal Statistics.Internal
    Statistics.Test.Internal Statistics.Types.Internal

import-dirs:          /usr/lib/ghc-9.0.1/site-local/statistics-0.15.2.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/statistics-0.15.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/statistics-0.15.2.0
hs-libraries:         HSstatistics-0.15.2.0-G7p0B75LaSC8lLGqvRXHtV
depends:
    aeson-1.5.6.0-Hu48mgwBrEQKjw91bueUbm
    async-2.2.3-9kX48PHnvdD9PjixjHg39U base-4.15.0.0
    base-orphans-0.8.5-LtEBU9Ms0DHOGKjXhH1L9 binary-0.8.8.0
    data-default-class-0.1.2.0-LBmwYNzg9cwLSaLiX5AQfC deepseq-1.4.5.0
    dense-linear-algebra-0.1.0.0-DsmAD3RO2sC564QMzhCJ7j
    math-functions-0.3.4.2-Kxgq30uxHawE6GNBSh9t1O
    monad-par-0.3.5-3IzOPdcTzI7AbprLxLuf9G
    mwc-random-0.15.0.2-F9pBT184lEuKRsA2wvCDWe
    primitive-0.7.2.0-JNIC7nP5sETC1HdsqczlAX
    vector-0.12.3.1-7avVqi4S14u4vwRbDqmIKr
    vector-algorithms-0.8.0.4-GMdc3OEcTfa7p5L6e0JRnk
    vector-binary-instances-0.2.5.2-E65ikTzKOEhLrJvfyA0U7t
    vector-th-unbox-0.2.1.9-JPUuVzx3XZ8BrrTa6Wc1RM

haddock-interfaces:   /usr/share/doc/haskell-statistics/html/statistics.haddock
haddock-html:         /usr/share/doc/haskell-statistics/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-statistics-0.15.2.0-195-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-statistics.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 statistics
version:              0.15.2.0
visibility:           public
id:                   statistics-0.15.2.0-BQFb7YsJFqBHwe6dBL9sYb
key:                  statistics-0.15.2.0-BQFb7YsJFqBHwe6dBL9sYb
license:              BSD-2-Clause
copyright:            2009-2014 Bryan O'\''Sullivan
maintainer:
    Bryan O'\''Sullivan <bos@serpentine.com>, Alexey Khudaykov <alexey.skladnoy@gmail.com>

author:
    Bryan O'\''Sullivan <bos@serpentine.com>, Alexey Khudaykov <alexey.skladnoy@gmail.com>

homepage:             https://github.com/bos/statistics
synopsis:             A library of statistical types, data, and functions
description:
    This library provides a number of common functions and types useful
    in statistics.  We focus on high performance, numerical robustness,
    and use of good algorithms.  Where possible, we provide
    references to the statistical literature.

    The library'\''s facilities can be divided into four broad categories:

    * Working with widely used discrete and continuous probability
    distributions.  (There are dozens of exotic distributions in use;
    we focus on the most common.)

    * Computing with sample data: quantile estimation, kernel density
    estimation, histograms, bootstrap methods, significance testing,
    and regression and autocorrelation analysis.

    * Random variate generation under several different distributions.

    * Common statistical tests for significant differences between
    samples.

category:             Math, Statistics
abi:                  72566ddefd54c7cd1eda0d89a58c71fe
exposed:              True
exposed-modules:
    Statistics.Autocorrelation Statistics.ConfidenceInt
    Statistics.Correlation Statistics.Correlation.Kendall
    Statistics.Distribution Statistics.Distribution.Beta
    Statistics.Distribution.Binomial
    Statistics.Distribution.CauchyLorentz
    Statistics.Distribution.ChiSquared
    Statistics.Distribution.DiscreteUniform
    Statistics.Distribution.Exponential
    Statistics.Distribution.FDistribution Statistics.Distribution.Gamma
    Statistics.Distribution.Geometric
    Statistics.Distribution.Hypergeometric
    Statistics.Distribution.Laplace Statistics.Distribution.Normal
    Statistics.Distribution.Poisson Statistics.Distribution.StudentT
    Statistics.Distribution.Transform Statistics.Distribution.Uniform
    Statistics.Function Statistics.Quantile Statistics.Regression
    Statistics.Resampling Statistics.Resampling.Bootstrap
    Statistics.Sample Statistics.Sample.Histogram
    Statistics.Sample.Internal Statistics.Sample.KernelDensity
    Statistics.Sample.KernelDensity.Simple Statistics.Sample.Normalize
    Statistics.Sample.Powers Statistics.Test.ChiSquared
    Statistics.Test.KolmogorovSmirnov Statistics.Test.KruskalWallis
    Statistics.Test.MannWhitneyU Statistics.Test.StudentT
    Statistics.Test.Types Statistics.Test.WilcoxonT
    Statistics.Transform Statistics.Types

hidden-modules:
    Statistics.Distribution.Poisson.Internal Statistics.Internal
    Statistics.Test.Internal Statistics.Types.Internal

import-dirs:          /usr/lib/ghc-9.0.1/site-local/statistics-0.15.2.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/statistics-0.15.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/statistics-0.15.2.0
hs-libraries:         HSstatistics-0.15.2.0-BQFb7YsJFqBHwe6dBL9sYb
depends:
    aeson-1.5.6.0-CI7TVKCpPUr3TvYJH78qPf
    async-2.2.3-JMLEcS5xCFd7RA7gdjgDSR base-4.15.0.0
    base-orphans-0.8.5-9z9ICLdGBEJIgnkGtwGCIi binary-0.8.8.0
    data-default-class-0.1.2.0-LBmwYNzg9cwLSaLiX5AQfC deepseq-1.4.5.0
    dense-linear-algebra-0.1.0.0-2SgPkxTAfrdA4VRm8WYmtR
    math-functions-0.3.4.2-56PqUgo36kMIFRTfjfMbyv
    monad-par-0.3.5-Hax27NXaSZLnn2IVDhEJr
    mwc-random-0.15.0.2-HaC3U2uIHMlCDVxVcP13WI
    primitive-0.7.2.0-DTPUl9Sg1wCEPhNK487zv2
    vector-0.12.3.1-1QSAcoQ4BjrEDZahKaKVTn
    vector-algorithms-0.8.0.4-HQn4at3zGahDO6SjfAITnz
    vector-binary-instances-0.2.5.2-IU1exEgvcwoIqDeJI7t9Ma
    vector-th-unbox-0.2.2-9PSAuQWFIKuGvkEGk69W0a

haddock-interfaces:   /usr/share/doc/haskell-statistics/html/statistics.haddock
haddock-html:         /usr/share/doc/haskell-statistics/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
